websauna.system is the core component of Websauna framework.

.. |ci| image:: https://img.shields.io/travis/websauna/websauna.system/master.svg?style=flat-square
    :target: https://travis-ci.org/websauna/websauna.system/

.. |cov| image:: https://codecov.io/github/websauna/websauna.system/coverage.svg?branch=master
    :target: https://codecov.io/github/websauna/websauna.system?branch=master

.. |latest| image:: https://img.shields.io/pypi/v/websauna.system.svg
    :target: https://pypi.python.org/pypi/websauna.system/
    :alt: Latest Version

.. |license| image:: https://img.shields.io/pypi/l/websauna.system.svg
    :target: https://pypi.python.org/pypi/websauna.system/
    :alt: License

.. |versions| image:: https://img.shields.io/pypi/pyversions/websauna.system.svg
    :target: https://pypi.python.org/pypi/websauna.system/
    :alt: Supported Python versions

+-----------+-----------+-----------+
| |versions|| |latest|  | |license| |
+-----------+-----------+-----------+
| |ci|      | |cov|     |           |
+-----------+-----------+-----------+

.. image:: https://websauna.org/theme/images/logo-768.png


It is automatically installed with the Websauna package, and can be used
standalone, with minimal requirements.

For documentation, examples, install, please check the main Websauna
project at https://github.com/websauna/websauna
